@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::SourceHutMeta;
 
-our $VERSION = '1.001'; # VERSION
+our $VERSION = '1.002'; # VERSION
 # ABSTRACT: Automatically include SourceHut meta information in META.yml
 
 use strict;
@@ -194,7 +194,7 @@ Dist::Zilla::Plugin::SourceHutMeta - Automatically include SourceHut meta inform
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -274,15 +274,7 @@ L<Dist::Zilla>, L<Dist::Zilla::Plugin::GithubMeta>
 
 =head1 CONTRIBUTING
 
-If you find any bugs or have improvement suggestions, please send them to me via email.
-
-=over
-
-=item * L<email + git|https://git-send-email.io/>
-
-=item * L<Sending patches upstream via SourceHut|https://man.sr.ht/git.sr.ht/#sending-patches-upstream>
-
-=back
+See file C<CONTRIBUTING.md>
 
 =head1 AUTHORS
 
